@@ -1,19 +1,21 @@
 #: Makefile/GraphViz.pm
 #: Plot the detailed structure of Makefiles
 #:   using GraphViz
-#: v0.03
+#: v0.04
 #: Copyright (c) 2005 Agent Zhang
-#: 2005-09-30 2005-10-05
+#: 2005-09-30 2005-10-15
 
 package Makefile::GraphViz;
 
 use strict;
 use warnings;
 
-use GraphViz;
+use GraphViz 0.07;
 use base 'Makefile::Parser';
 
-our $VERSION = '0.03';
+$Makefile::Parser::Strict = 0;
+
+our $VERSION = '0.04';
 
 our $IDCounter = 0;
 
@@ -227,7 +229,7 @@ Makefile::GraphViz - Plot the Detailed Structure of Makefiles Using GraphViz
 This module uses L<Makefile::Parser> to render user's Makefiles via the amazing
 L<GraphViz> module. Before I decided to write this thing, there had been already a
 CPAN module named L<GraphViz::Makefile> which did the same thing. However, the
-pictures generated by L<GraphViz::Makefile> is oversimplified in my opinion, So
+pictures generated by L<GraphViz::Makefile> is oversimplified in my opinion, so
 a much complex one is still needed.
 
 B<IMPORTANT!>
@@ -235,10 +237,19 @@ This stuff is highly experimental and is currently at B<ALPHA> stage, so
 production use is strongly discouraged. Anyway, I have the plan to 
 improve this stuff unfailingly.
 
+=head1 INSTALLATION
+
+Prerequisites L<GraphViz> and L<Makefile::Parser> should be installed to your
+Perl distribution first. Among other things, the L<GraphViz> module needs tools
+"dot", "neato", "twopi", "circo" and "fdp" from the Graphviz project
+(L<http://www.graphviz.org/> or L<http://www.research.att.com/sw/tools/graphviz/>).
+Hence you have to download an executable package of AT&T's Graphviz for your platform
+or build it from source code yourself.
+
 =head1 The Makefile::GraphViz Class
 
 This class is a subclass inherited from L<Makefile::Parser>. So all the methods (and
-hence all the functionalities) provided by L<Makefile::Parser> are accessable here.
+hence all the functionalities) provided by L<Makefile::Parser> are accessible here.
 Additionally this class also provides some more methods on its own right.
 
 =head1 METHODS
@@ -294,7 +305,7 @@ which is default to red directed arrows.
 =item end_with
 
 This option takes a list ref as its value. The plot method
-won't continue to interate the subtree rooted at entries in the
+won't continue to iterate the subtree rooted at entries in the
 list. It is worth noting that the entries themselves will be
 displayed as usual. This is the only difference compared to
 the B<exclude> option.
@@ -319,7 +330,7 @@ these entries won't be displayed either.
 
 =item gv
 
-This option accetps user's GraphViz object to render the graph.
+This option accepts user's GraphViz object to render the graph.
 
     $gv = GraphViz->new(width => 30, height => 20,
                         pagewidth => 8.5, pageheight => 11);
@@ -440,6 +451,12 @@ L<Devel::Cover> report on this module test suite.
     Total                         100.0   90.9   69.0  100.0  100.0  100.0   90.9
     ---------------------------- ------ ------ ------ ------ ------ ------ ------
 
+=head1 REPOSITORY
+
+For the very latest version of this module, check out the source from
+L<https://svn.openfoundry.org/makefilegv> (Subversion). There is
+anonymous access to all.
+
 =head1 BUGS
 
 Please report bugs or send wish-list to
